@@ -111,7 +111,7 @@ public:
     bool isFoldersPanelEnabled() const;
     bool isInformationPanelEnabled() const;
 
-public slots:
+public Q_SLOTS:
     /**
      * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
      * 2 directories are collected within one tab.
@@ -170,16 +170,11 @@ public slots:
     void quit();
 
     /**
-     * Opens a new tab and places it after the current tab
+     * Opens a new tab in the background showing the URL \a url.
      */
-    void openNewTabAfterCurrentTab(const QUrl& url);
+    void openNewTab(const QUrl& url);
 
-    /**
-     * Opens a new tab and places it as the last tab
-     */
-    void openNewTabAfterLastTab(const QUrl& url);
-
-signals:
+Q_SIGNALS:
     /**
      * Is sent if the selection of the currently active view has
      * been changed.
@@ -221,7 +216,7 @@ protected:
     /** Handles QWhatsThisClickedEvent and passes all others on. */
     bool eventFilter(QObject*, QEvent*) override;
 
-protected slots:
+protected Q_SLOTS:
     /**
      * Calls the base method KXmlGuiWindow::saveNewToolbarConfig().
      * Is also used to set toolbar constraints and UrlNavigator position
@@ -229,7 +224,7 @@ protected slots:
      */
     void saveNewToolbarConfig() override;
 
-private slots:
+private Q_SLOTS:
     /**
      * Refreshes the views of the main window by recreating them according to
      * the given Dolphin settings.
@@ -312,6 +307,7 @@ private slots:
     void disableStopAction();
 
     void showFilterBar();
+    void toggleFilterBar();
 
     /**
      * Toggles between edit and browse mode of the navigation bar.
@@ -416,11 +412,6 @@ private slots:
      */
     void addToPlaces();
 
-    /**
-     * Opens a new tab in the background showing the URL \a url.
-     */
-    void openNewTab(const QUrl& url, DolphinTabWidget::TabPlacement tabPlacement);
-
     /**
      * Opens the selected folder in a new tab.
      */
