@@ -32,6 +32,7 @@ class KItemListWidgetInformant;
 class KItemListWidgetCreatorBase;
 class QTimer;
 class QPropertyAnimation;
+class QVariantAnimation;
 
 /**
  * @brief Represents the view of an item-list.
@@ -269,7 +270,7 @@ public:
 
     void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = nullptr) override;
 
-signals:
+Q_SIGNALS:
     void scrollOrientationChanged(Qt::Orientation current, Qt::Orientation previous);
     void scrollOffsetChanged(qreal current, qreal previous);
     void maximumScrollOffsetChanged(qreal current, qreal previous);
@@ -377,7 +378,7 @@ protected:
     virtual void updateFont();
     virtual void updatePalette();
 
-protected slots:
+protected Q_SLOTS:
     virtual void slotItemsInserted(const KItemRangeList& itemRanges);
     virtual void slotItemsRemoved(const KItemRangeList& itemRanges);
     virtual void slotItemsMoved(const KItemRange& itemRange, const QList<int>& movedToIndexes);
@@ -391,7 +392,7 @@ protected slots:
     virtual void slotCurrentChanged(int current, int previous);
     virtual void slotSelectionChanged(const KItemSet& current, const KItemSet& previous);
 
-private slots:
+private Q_SLOTS:
     void slotAnimationFinished(QGraphicsWidget* widget,
                                KItemListViewAnimation::AnimationType type);
     void slotLayoutTimerFinished();
@@ -747,6 +748,8 @@ private:
     // by KItemListView::showDropIndicator() and KItemListView::hideDropIndicator().
     QRectF m_dropIndicator;
 
+    QList<QVariantAnimation*> m_rubberBandAnimations;
+
     friend class KItemListContainer; // Accesses scrollBarRequired()
     friend class KItemListHeader;    // Accesses m_headerWidget
     friend class KItemListController;
