@@ -50,7 +50,7 @@ public:
 
     QList<QAction*> actions(const KFileItemList& items) const;
 
-signals:
+Q_SIGNALS:
     /**
      * Is emitted if an information message with the content \a msg
      * should be shown.
@@ -69,7 +69,7 @@ signals:
      */
     void operationCompletedMessage(const QString& msg);
 
-private slots:
+private Q_SLOTS:
     /**
      * Invokes verifyDirectory() with a small delay. If delayedDirectoryVerification()
      * is invoked before the delay has been exceeded, the delay will be reset. This
@@ -101,7 +101,6 @@ private slots:
 
 private:
     typedef QPair<KFileItem, KVersionControlPlugin::ItemVersion> ItemState;
-    typedef QPair<KVersionControlPlugin*, QString> VCSPlugin;
 
     void updateItemStates();
 
@@ -133,10 +132,12 @@ private:
     bool isVersionControlled() const;
 
 private:
+    void initPlugins();
+
     bool m_pendingItemStatesUpdate;
-    bool m_versionedDirectory;
     bool m_silentUpdate; // if true, no messages will be send during the update
                          // of version states
+    QString m_localRepoRoot;
 
     DolphinView* m_view;
     KFileItemModel* m_model;
@@ -145,7 +146,7 @@ private:
 
     bool m_pluginsInitialized;
     KVersionControlPlugin* m_plugin;
-    QList<VCSPlugin> m_plugins;
+    QList<QPointer<KVersionControlPlugin>> m_plugins;
     UpdateItemStatesThread* m_updateItemStatesThread;
 
     friend class UpdateItemStatesThread;
